'''Data loader module.
'''

import os, pickle
import pygame
from myFrames import *

data_dir = os.path.normpath(os.path.join('data'))
levels_dir = os.path.normpath(os.path.join('levels'))
audio_dir = os.path.normpath(os.path.join('audio'))
font_dir = os.path.normpath(os.path.join('font'))
save_dir = os.path.normpath(os.path.join('save'))

listOfFiles={'images':[],'backgrounds':[],'sounds':[],'fonts':[]}
for f in os.listdir(data_dir):
    if f[-3:] in ('png'):
        listOfFiles['images'].append(f)
    elif f[-3:] in ('jpg'):
        listOfFiles['backgrounds'].append(f)
    elif f[-3:] in ('mp3'):
        listOfFiles['sounds'].append(f)
    elif f[-3:] in ('ttf'):
        listOfFiles['fonts'].append(f)
#print listOfFiles 

#Data folder is located in "data" folder under root directory
def filepath(folder, filename):
    '''Determine the path to a file in the data directory.
    '''
    return os.path.join(folder, filename)

#Standard load file function
def load(folder, filename, mode='rb'):
    '''Open a file in the data directory.
    "mode" is passed as the second arg to open().
    '''
    return open(filepath(folder, filename), mode)

def loadgame(filename):
	print 'Loading data from file',filepath(save_dir, filename)
	f = open(filepath(save_dir, filename), 'r')
	inventory = pickle.load(f)
	f.close()
	return inventory

def savegame(filename, inventory):
	print 'Saving data on file',filepath(save_dir, filename)
	f = open(filepath(save_dir, filename), 'w')
	pickle.dump(inventory, f)
	f.close()


def load_font(filename):
	return filepath(font_dir, filename)
	
def load_level(filename, mode='rb'):
	return open(filepath(levels_dir, filename), mode)
	
def load_image(filename, size=[None,None]):
    '''Loads image returning pygame.image object.
    Complete filename is mandatory argument.
    Size is optional argument.
        If specified, it will be used to resize the output image objects (width,heigth).
        If not specified, image will be loaded with its own dimension.
    '''
    #originalImage = pygame.image.load(filepath(data_dir,filename)).convert()
    originalImage = pygame.image.load(filepath(data_dir,filename)).convert_alpha()
    if size<>[None,None]:
        scaledImage = pygame.transform.scale(originalImage,[size[0], size[1]])
        scaledImage=scaledImage.convert_alpha()
        return scaledImage
    return originalImage

def getImageFileNames():
    '''Get names of all the images in the datadir directory.'''
    imageFileNames=[]
    for f in os.listdir(data_dir):
        ext=f[-3:]
        if ext in ('png','jpg'):
            imageFileNames.append(f)
    return imageFileNames    


def load_music(filename):
    '''Loads music
    '''
    pygame.mixer.music.load(filepath(audio_dir,filename))
    pygame.mixer.music.set_volume(0.7)


def load_all_sounds():
    '''Loads all the sounds effects that will be used in the game.
    '''
    mySounds={}
    print 'Loading audio...'
    for f in os.listdir(audio_dir):
        name,ext=f[:-4],f[-3:]
        if ext in ('ogg'):
            print name
            mySounds[name]=pygame.mixer.Sound(filepath(audio_dir,f))
            mySounds[name].set_volume(0.3)
    return mySounds            

